summaryrefslogtreecommitdiff
path: root/nuttx/configs/avr32dev1/src/up_boot.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/avr32dev1/src/up_boot.c')
-rw-r--r--nuttx/configs/avr32dev1/src/up_boot.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/configs/avr32dev1/src/up_boot.c b/nuttx/configs/avr32dev1/src/up_boot.c
index 0763ecfcf..75f0e9e71 100644
--- a/nuttx/configs/avr32dev1/src/up_boot.c
+++ b/nuttx/configs/avr32dev1/src/up_boot.c
@@ -63,16 +63,16 @@
************************************************************************************/
/************************************************************************************
- * Name: up_boardinitialize
+ * Name: at32uc3_boardinitialize
*
* Description:
* All AVR32 architectures must provide the following entry point. This entry point
* is called early in the intitialization -- after all memory has been configured
* and mapped but before any devices have been initialized.
*
************************************************************************************/
-void up_boardinitialize(void)
+void at32uc3_boardinitialize(void)
{
/* Configure SPI chip selects */
@@ -63,16 +63,16 @@
*
* Description:
- * All AVR32 architectures must provide the following entry point. This entry point
- * is called early in the intitialization -- after all memory has been configured
- * and mapped but before any devices have been initialized.
+ * All AVR32 AT32UC3 architectures must provide the following entry point. This
+ * entry point is called early in the initialization -- after all memory has been
+ * configured and mapped but before any devices have been initialized.
*
************************************************************************************/